/*********************************************************************
**  Device:   A9139M0
**  File:     main.c
**  Target:   A9139M0
**  Tools:    ICE
**  Updated:  2024-03-25
**  Description:
**  This file is a sample code for your reference.
**
**  Copyright (C) 2024 AMICCOM Corp.
**
*********************************************************************/
#define _MAIN_VAL_

#include "ADC12B.h"
#include "main.h"
#include "function.h"
#include "ExternVar.h"
#include "system_A9139M0.h"

//#define _IO_SET_MODE_
//#define _MASTER_MODE_

extern const uint8_t ID_MAC_ADDRESS[8];

/*********************************************************************/

const Uint8 ID_Tab[4] = {0x34, 0x75, 0xC5, 0x8C}; //, 0xC7, 0x33, 0x45, 0xE7}; //ID code for FAE
//const Uint8 ID_Tab[4] = {0x75, 0x34, 0x8C, 0xC5}; //, 0xC7, 0x33, 0x45, 0xE7}; //ID code

const Uint32 FreqChannel_Tab[3] =
{  
  //PLL2  PLL3  PLL4
    0x00875014,  //freq 433.001MHz
    0x00879014,  //freq 433.801MHz
    0x0087D014,  //freq 434.601MHz
};

/*****************************************************************************
**  ROUTINE NAME: uartTx                                                 **
*****************************************************************************/
void UartTx(Uint8 length)
{
    Uart_TxLen = 0;
    Uart_TxCnt = length;
    UART0->DATA = UartBuffer[Uart_TxLen];
}

/*****************************************************************************
**  FUNCTION    : init UART0 for UART                                       **
*****************************************************************************/
void InitUART0(void)
{
    Uint32 baudrate;

    // 12.8MHz, 230400KHz
    baudrate = 230400; 
    UART0->BAUDDIV = SystemCoreClock / baudrate; 
    UART0->CTRL = 0x0F; 
    GPIO0->ALTFUNCSET |=  BIT16 | BIT17;
    NVIC_EnableIRQ( UART0_IRQn );
}

/*****************************************************************************
**  Function    : InitLink                                    
*****************************************************************************/

void InitLink(void)
{
#ifdef _IO_SET_MODE_
    if ( GPIO0->DATA_PIN.P11 ) //master
    {
        InitMaster();
    }
    else  //P3_5=0, slave
    {
        InitSlave();
    }
#else

#ifdef _MASTER_MODE_
        InitMaster();
#else
        InitSlave();
#endif

#endif
    AddressID[0] = ID_MAC_ADDRESS[5];
    AddressID[1] = ID_MAC_ADDRESS[4];
    
}

/*****************************************************************************
**  Function    : Master Tx Data Set                                    
*****************************************************************************/
void MasterTxDatatSet(void)
{
    Uint16 slot;
    Uint8  i;
    
    slot = MasterSlot;

    //for (slot = 0 ;slot<MAXSLAVENODE; slot++)
    {
        //MasterSlaveTxBuff[slot][0] = CBYTE[ID_ADDRSSS + 6];
        //MasterSlaveTxBuff[slot][1] = CBYTE[ID_ADDRSSS + 7];
        if (NodeState[slot]==DATA_STATE)
        {
            MasterSlaveTxBuff[2] = MasterSlaveTxBuff[2]+1;
            //MasterSlaveTxBuff[slot][2] = MasterSlaveTxBuff[slot][1];
            MasterSlaveTxBuff[3] = MasterSlaveTxBuff[2];
            MasterSlaveTxBuff[4] = MasterSlaveTxBuff[3];
        }
    }
    for (i=5;i<DATA_Length;i++)
    {
        MasterSlaveTxBuff[i] = i;//MasterSlaveRxBuff[SlaveNodeNum][i];// | 0x80;
    }
}

/*****************************************************************************
**  Function    : Master Tx Data Set                                    
*****************************************************************************/
void TxDatatInit(void)
{
    Uint8 i;
    
    //slot = MasterSlot;

    //for (slot = 0 ;slot<MAXSLAVENODE; slot++)
    {
        for (i=0;i<DATA_Length;i++)
        {
            MasterSlaveTxBuff[i] = i;//MasterSlaveRxBuff[SlaveNodeNum][i];// | 0x80;
        }
    }
}

/*****************************************************************************
**  Function    : Master Uart Output                                    
*****************************************************************************/
void MasterUartOut(void)
{
    Uint16 i;
    Uint8 lost;
    Uint8 receive;
    Uint8 disconnect;
    Uint16 slot;
    
    slot = MasterSlot;
    //for (slot = 0 ;slot<MAXSLAVENODE; slot++)
    {
        lost = NodeLost[slot];
        receive = NodeReceive[slot];
        disconnect = NodeDisconnect[slot];
        
        if (NodeState[slot]==DATA_STATE)
        {
            UartBuffer[0] = 'D';
            UartBuffer[1] = 'a';
            UartBuffer[2] = 't';
            UartBuffer[3] = 'a';
            UartBuffer[4] = '_';
            i = slot;
            if (i>999)
            {
                i = i/1000;
                UartBuffer[5] = '0'+i;
                
            }
            else
            {
                UartBuffer[5] = '0';
            }
            
            i = slot%1000;
            if (i>99)
            {
                i = i/100;
                UartBuffer[6] = '0'+i;
                
            }
            else
            {
                UartBuffer[6] = '0';
            }

            i = slot%100;
            if (i>9)
            {
                i = i/10;
                UartBuffer[7] = '0'+i;
                
            }
            else
            {
                UartBuffer[7] = '0';
            }
            
            i = slot%10;
            UartBuffer[8] = '0'+ i;

            UartBuffer[9] = ' ';
            if (receive>99)
            {
                i = receive/100;
                UartBuffer[10] = '0' + i;
                receive = receive % 100;
            }
            else
                UartBuffer[10] = ' ';
            
            if (NodeReceive[slot]>9)
            {
                i = receive/10;
                UartBuffer[11] = '0' + i;
                receive = receive % 10;
            }
            else
                UartBuffer[11] = ' ';
            UartBuffer[12] = '0'+receive;
            UartBuffer[13] = ' ';
            if (lost>99)
            {
                i = lost/100;
                UartBuffer[14] = '0' + i;
                lost = lost % 100;
            }
            else
                UartBuffer[14] = ' ';
            
            if (NodeLost[slot]>9)
            {
                i = lost/10;
                UartBuffer[15] = '0' + i;
                lost = lost % 10;
            }
            else
                UartBuffer[15] = ' ';
            UartBuffer[16] = '0'+lost;
            UartBuffer[17] = ' ';
            if (disconnect>99)
            {
                i = disconnect/100;
                UartBuffer[18] = '0' + i;
                disconnect = disconnect % 100;
            }
            else
                UartBuffer[18] = ' ';
            
            if (NodeDisconnect[slot]>9)
            {
                i = disconnect/10;
                UartBuffer[19] = '0' + i;
                disconnect = disconnect % 10;
            }
            else
                UartBuffer[19] = ' ';
            UartBuffer[20] = '0'+disconnect;

            receive = 21;
            if (Flag1.bit.MasterDataOkFlag)
            {
                //for (i=0;i<5;i++)
                for (i=0;i<DATA_Length;i++)
                {
                    UartBuffer[receive] = ' ';
                    receive++;
                    lost = (MasterSlaveRxBuff[i])>>4;
                    if (lost>9)
                        UartBuffer[receive] = 'A'+lost-10;
                    else
                        UartBuffer[receive] = '0'+lost;
                    receive++;
                    lost = (MasterSlaveRxBuff[i])&0x0F;
                    if (lost>9)
                        UartBuffer[receive] = 'A'+lost-10;
                    else
                        UartBuffer[receive] = '0'+lost;
                    receive++;
                }
            }
    
            UartBuffer[receive++] = 0x0D;
            UartBuffer[receive++] = 0x0A;
            UartTx(receive);
        
        }
        else
        {
            if (NodeState[slot]==LINK_STATE)
            {
                UartBuffer[0] = 'L';
                UartBuffer[1] = 'i';
                UartBuffer[2] = 'n';
                UartBuffer[3] = 'k';
            }
            else
            {
                UartBuffer[0] = 'A';
                UartBuffer[1] = 's';
                UartBuffer[2] = 's';
                UartBuffer[3] = 'i';
            }

            UartBuffer[4] = '_';

            i = slot;
            if (i>999)
            {
                i = i/1000;
                UartBuffer[5] = '0'+i;
                
            }
            else
            {
                UartBuffer[5] = '0';
            }
            
            i = slot%1000;
            if (i>99)
            {
                i = i/100;
                UartBuffer[6] = '0'+i;
                
            }
            else
            {
                UartBuffer[6] = '0';
            }

            i = slot%100;
            if (i>9)
            {
                i = i/10;
                UartBuffer[7] = '0'+i;
                
            }
            else
            {
                UartBuffer[7] = '0';
            }
            
            i = slot%10;
            UartBuffer[8] = '0'+ i;

            UartBuffer[9] = ' ';
            if (receive>99)
            {
                i = receive/100;
                UartBuffer[10] = '0' + i;
                receive = receive % 100;
            }
            else
                UartBuffer[10] = ' ';
            
            if (NodeReceive[slot]>9)
            {
                i = receive/10;
                UartBuffer[11] = '0' + i;
                receive = receive % 10;
            }
            else
                UartBuffer[11] = ' ';
            UartBuffer[12] = '0'+receive;
            UartBuffer[13] = ' ';
            if (lost>99)
            {
                i = lost/100;
                UartBuffer[14] = '0' + i;
                lost = lost % 100;
            }
            else
                UartBuffer[14] = ' ';
            
            if (NodeLost[slot]>9)
            {
                i = lost/10;
                UartBuffer[15] = '0' + i;
                lost = lost % 10;
            }
            else
                UartBuffer[15] = ' ';
            UartBuffer[16] = '0'+lost;
            UartBuffer[17] = ' ';
            if (disconnect>99)
            {
                i = disconnect/100;
                UartBuffer[18] = '0' + i;
                disconnect = disconnect % 100;
            }
            else
                UartBuffer[18] = ' ';
            
            if (NodeDisconnect[slot]>9)
            {
                i = disconnect/10;
                UartBuffer[19] = '0' + i;
                disconnect = disconnect % 10;
            }
            else
                UartBuffer[19] = ' ';
            UartBuffer[20] = '0'+disconnect;
            UartBuffer[21] = 0x0D;
            UartBuffer[22] = 0x0A;
            UartTx(23);
        }
    }
}

/*****************************************************************************
**  Function    : Master Uart Output                                    
*****************************************************************************/
void SlaveUartOut(void)
{
    Uint8 i;
    Uint8 j;
    Uint8 tmp;
    
        
    UartBuffer[0] = 'D';
    UartBuffer[1] = 'a';
    UartBuffer[2] = 't';
    UartBuffer[3] = 'a';
    UartBuffer[4] = '_';
    if (SlaveNodeNum>9)
    {
        i = SlaveNodeNum/10;
        UartBuffer[5] = '0'+i;
        i = SlaveNodeNum%10;
        UartBuffer[6] = '0'+ i;
        //UartBuffer[5] = '1';
        //UartBuffer[6] = '0'+ SlaveNodeNum-10;
    }
    else
    {
        UartBuffer[5] = '0'+ SlaveNodeNum;
        UartBuffer[6] = ' ';
    }
    UartBuffer[7] = ' ';

    j = 8;
    for (i=0;i<DATA_Length;i++)
    {
        UartBuffer[j] = ' ';
        j++;
        tmp = (MasterSlaveRxBuff[i])>>4;
        if (tmp>9)
            UartBuffer[j] = 'A'+tmp-10;
        else
            UartBuffer[j] = '0'+tmp;
        j++;
        tmp = (MasterSlaveRxBuff[i])&0x0F;
        if (tmp>9)
            UartBuffer[j] = 'A'+tmp-10;
        else
            UartBuffer[j] = '0'+tmp;
        j++;
    }

    UartBuffer[j++] = 0x0D;
    UartBuffer[j++] = 0x0A;
    UartBuffer[j++] = 0xFF;
    UartTx(j);
}

/*****************************************************************************
**  Function    : Master Tx Data Set                                    
*****************************************************************************/
void SlaveTxDatatSet(void)
{
    Uint8 i;
    
    /*for (i=0;i<DATA_Length;i++)
    {
        MasterSlaveTxBuff[SlaveNodeNum][i] = MasterSlaveRxBuff[SlaveNodeNum][i];// | 0x80;
    }*/
    MasterSlaveTxBuff[0] = AddressID[1];//ID_MAC_ADDRESS[6];
    MasterSlaveTxBuff[1] = AddressID[0];//ID_MAC_ADDRESS[7];
    MasterSlaveTxBuff[2] = TestDataCnt0;
    MasterSlaveTxBuff[3] = TestDataCnt1;
    MasterSlaveTxBuff[4] = TestDataCnt2;
    
    ADC_Val_L = (Uint8)ADC_Val;
    ADC_Val_H = (Uint8)(ADC_Val>>8);
    MasterSlaveTxBuff[5] = ADC_Val_L;
    MasterSlaveTxBuff[6] = ADC_Val_H;
    
    for (i=7;i<DATA_Length;i++)
    {
        MasterSlaveTxBuff[i] = i;//MasterSlaveRxBuff[SlaveNodeNum][i];// | 0x80;
    }
}

//extern Uint16  data    Check_stable;

/******************************************************************************
**  Function   : timer0Isr                                                   **
**                                                                           **
**  Description:                                                             **
**                                                                           **
******************************************************************************/
void Uart0_interrupt(void)
{
    if( UART0->INTSTATUS & 0x01 ) //TX
    {
        UART0->INTCLEAR = 0x01; //TI clear
        Uart_TxLen++;

        if (Uart_TxLen<Uart_TxCnt)
        {
            UART0->DATA = UartBuffer[Uart_TxLen];
        }
    }

    if ( UART0->INTSTATUS & 0x02 ) //RX
    {
        UART0->INTCLEAR = 0x02; //RI clear
    }
}


/************************************************************************
**  RTC_Enable
************************************************************************/
void RTC_Enable ( void )
{   
		Uint8 rtcap;
		
		rtcap = 16;		
		GPIO0->PUN &= ( ~( BIT22 | BIT23 ) );
		GPIO0->OUTENABLECLR = BIT22 | BIT23;
		POWER->PWR_TA = 0xAAAAAAAA;
    POWER->PWR_TA = 0x55555555;				
		POWER->IO_CTRL2 = 0x0000003F; 		
		RCCTRL1_Reg = ( ( RCCTRL1_Reg & ~0x00F88016 ) | BIT1 | BIT2 | BIT4 | BIT15 | ( ( rtcap & 0x1F ) << 19 ) ); //b1:TMRE=1, b2:RCTS=1, b4:MAN=1, b15:RLVS=1, b19~b23:RTCAP=16
		POWER->RCCTRL1 = RCCTRL1_Reg; 
		RCCTRL2_Reg = ( ( RCCTRL2_Reg & ~0x000703FF ) | 0x00040012 ); //b0~9:MRCT=18, b16~18:RCOT=4
		POWER->RCCTRL2 = RCCTRL2_Reg;
		Delay1ms(300); //RC settling time 
}

//Rfc
/*********************************************************************
** WriteFIFO
*********************************************************************/
void WriteFIFO( const Uint8* buf, Uint8 size )
{
    Uint32 i;
		RFLIB_Reset( TXPOINT_RST );	
		for ( i = 0; i < size; i++ )
		    RADIO->TX_DATA[i] = buf[i];
}

/************************************************************************
**  WriteID
************************************************************************/
Uint8 WriteID ( void )
{
    Uint32 tmp1,tmp2;

    //Write ID
    tmp1 = ID_Tab[0]<<24 | ID_Tab[1]<<16 | ID_Tab[2]<<8 | ID_Tab[3];
    RFLIB_WriteID(tmp1);   
   
    //Read ID   
    tmp2 = RFLIB_ReadID();  
   
    //check ID
    if ( tmp1 != tmp2 )
        return FAIL;

    return PASS;
}

/************************************************************************
**  Reg_Init
************************************************************************/
void Reg_Init ( void )
{
		//CONFIG INDEX in A9139M0_RFLIB.h.		
  	CODE1_Reg = A9139M0_Config[INDEX_CODE1].load[ConfigType]; 
		FIFO_Reg = A9139M0_Config[INDEX_FIFO].load[ConfigType]; 
		TXPWR_Reg = A9139M0_Config[INDEX_TXPWR].load[ConfigType];				 	
		GPIO_Reg = A9139M0_Config[INDEX_GPIO].load[ConfigType]; 
		PWRCTL2_Reg = A9139M0_Config[INDEX_PWRCTL2].load[ConfigType]; 
		FPCTL_Reg = A9139M0_Config[INDEX_FPCTL].load[ConfigType]; 
		ADC_Reg = A9139M0_Config[INDEX_ADC].load[ConfigType];
		RTH_Reg = A9139M0_Config[INDEX_RTH].load[ConfigType];
		ADC12B_CTL_Reg = A9139M0_Config[INDEX_12BADC_CTL].load[ConfigType];
		RCCTRL1_Reg = A9139M0_Config[INDEX_RCCTL1].load[ConfigType];
		RCCTRL2_Reg = A9139M0_Config[INDEX_RCCTL2].load[ConfigType];
		INTIE_Reg = A9139M0_Config[INDEX_INTIE].load[ConfigType];
		SYN_Reg = A9139M0_Config[INDEX_SYN].load[ConfigType];
		SYCK_Reg = A9139M0_Config[INDEX_SYCK].load[ConfigType];
		RXCTL_Reg = A9139M0_Config[INDEX_RXCTL].load[ConfigType];
}

/************************************************************************
**  IDLength
************************************************************************/
void IDLength ( Uint32 idl )
{
		CODE1_Reg = ( ( CODE1_Reg & ~0x00C00000 ) | ( ( idl & 0x03 ) << 22 ) );			
		RADIO->CODE1 = CODE1_Reg;		
}

#define ID_4BYTES    				0x01
/************************************************************************
**  UserRegister
************************************************************************/
void UserRegister ( void )
{
		Reg_Init();
	
		IDLength ( ID_4BYTES ); 		
	  if ( WriteID() ) 
		    Err_State(); 

		/* 
								|	CFG1     	|	CFG2		  | CFG3		  | CFG4			| CFG5      | CFG6      | CFG7
		Frequency   | 433MHz    |	433MHz		| 433MHz		| 433MHz		| 433MHz	  | 433MHz    | 433MHz
	  Data Rate	  | 9.6kbps	  |	50kbps		|	100kbps	  |	150kbps   |	250kbps   |	500kbps   |	2Mbps 
	  IFBW		    | 100KHz	  |	50KHz		  |	100KHz	  |	150KHz    |	250KHz    |	250KHz    |	250KHz 
		Fdev		    | 37.5KHz	  |	18.75KHz	|	37.5KHz	  |	56.25KHz  |	93.75KHz  |	187.5KHz  |	498.05KHz
	  Crystal     | 12.8MHz		|	12.8MHz		|	12.8MHz	  | 19.2MHz   | 16.0MHz   | 16.0MHz   | 16.0MHz				
    
		0x50001020 , 0x0000003F, 0x0000003F, 0x0000003F, 0x0000003F, 0x0000003F, 0x0000003F, 0x0000003F  //[0020] FIFO                                
		0x50001024 , 0x00040009, 0x00030000, 0x00030000, 0x00050000, 0x000B0000, 0x000B0000, 0x000E0000  //[0024] SYCK                                
		0x50001028 , 0x07000000, 0x07000000, 0x07000000, 0x07000000, 0x07000000, 0x07000000, 0x07000000  //[0028] GPIO                                		  
		0x50001104 , 0x0007027E, 0x0007027E, 0x0007027E, 0x0007027E, 0x0007027E, 0x0007027E, 0x0007027E  //[0104] TXPWR 
		0x50001174 , 0x3D580300, 0x3D580300, 0x3D580300, 0x3D580300, 0x3D580300, 0x3D580300, 0x3D580B00  //[0174] CODE1 
	
		*/
		
		//Default CFG3 100kbps

		FIFO_Reg = 0x0000003F; //b0~b25:FEP, lengths=FEP+1  
		RADIO->FIFOCTRL = FIFO_Reg;		
				
		SYCK_Reg = 0x00030000; //b0~b7:SDR, Data rate=Data rate/(SDR+1)  
		RADIO->SYCK = SYCK_Reg;		
		
		GPIO_Reg = 0x07000000; //RFIO	 
		RADIO->RFGIO = GPIO_Reg;	
		
		TXPWR_Reg = 0x0007027E;	//b0~b5:TBG, b6~b7:PAC, b8~b9:TDC, 62/1/2 
		RADIO->TXPOWER = TXPWR_Reg;					
    
		//IDL[1:0]: [00]:2bytes, [01]:4bytes, [10]:6bytes, [11]:8bytes 
		CODE1_Reg = 0x3D580300; //b22~b23:IDL, 4bytes
		RADIO->CODE1 = CODE1_Reg;			
		
}

/************************************************************************
**  CrystalSelect
************************************************************************/
void CrystalSelect ( void )
{
    switch ( ConfigType ) 
    {	
				case 3: //19.2   
				SystemCoreClock = ( 19200000UL ); 
				break;
							
				case 4://16		
				case 5:
				case 6:
				SystemCoreClock = ( 16000000UL ); 
				break;
							
				case 0://12.8
				case 1:
				case 2:
				SystemCoreClock = ( 12800000UL ); 
				break;    
    }

}

/*********************************************************************
** RF_SetBBIO
*********************************************************************/
void RF_SetBBIO ( Uint32 gio1s, Uint32 gio2s, Uint32 ckos, Uint8 sw )
{
    GPIO_Reg = ( ( GPIO_Reg & ~0x070F0F0F ) | ( ckos << 16 ) | ( gio2s << 8 ) | gio1s );		

    if ( ( Uint8 ) sw )
    {
        GPIO0->ALTFUNCSET |= BIT13 | BIT14 | BIT15; //Set GPIO0 BIT13->BB_GIO1 ,BIT14->BB_GIO2, BIT11->BB_CKO
        GPIO0->OUTENABLESET |= BIT13 | BIT14 | BIT15; //Set GPIO0 BIT13->BB_GIO1 ,BIT14->BB_GIO2, BIT11->BB_CKO
				GPIO_Reg |= BIT24 | BIT25 | BIT26; //b24:CKOIOS=1, b25:GIO2IOS=1, b26:GIO1IOS=1
    }
    else
    {
        GPIO0->ALTFUNCCLR |= BIT13 | BIT14 | BIT15; //CLEAR GPIO0 BIT13->BB_GIO1 ,BIT14->BB_GIO2, BIT11->BB_CKO
        GPIO0->OUTENABLECLR |= BIT13 | BIT14 | BIT15; //CLEAR GPIO0 BIT13->BB_GIO1 ,BIT14->BB_GIO2, BIT11->BB_CKO
    }
		
		RADIO->RFGIO = GPIO_Reg;		
}

/*********************************************************************
* main loop
*********************************************************************/
int main ( void )
{   
    Uint8 i;
    Uint8 UartOutFlag;
    Uint8 CalResult;

    while ( ( GPIO0->DATA & BIT12 ) == 0 ); //Wait Debug Pin(P0.12) Go High
    
    ConfigType = SelectConfig;
    __disable_irq();
    // Clear reset flag

		//Initial HW
    InitMCU();
		CrystalSelect();
	
		RFLIB_InitCrystalCL ( 28 ); //CrystalCL 0x1C(20pF)
	  Delay100us ( 5 ); //Delay 500us For Regulator Stabilized   
		RFLIB_Reset ( RF_RST );			
		CalResult = RFLIB_InitRF();
    if ( CalResult ) //Check Return Value In A9139M0_RFLIB.h 
		    Err_State(); 
		
		RFLIB_StrobeCmd ( CMD_STBY );
		
		//User define
		UserRegister();		

    PWRCTL1_Reg = A9139M0_Config[INDEX_PWRCTL1].load[ConfigType]; 
    POWER->PWR_TA = 0xAAAAAAAA;
    POWER->PWR_TA = 0x55555555;
    POWER->POWERCTRL1 = PWRCTL1_Reg & 0xFFBFFFFF ;//RGS Bit22 = 0
		/*                    
    How to set the MCU clock to High Speed Mode 
    Step1 : HS Enable(XREF_PLL = 51.2MHz)
    Step2 : Cache Enable(Improve in code fetching performance)

    Note : For Data Rate = 100Kbps / Xtal = 12.8MHz / XREF_PLL = 51.2MHz 
    If user wanna change CFG, Xtal or XREF_PLL Frequency, please consult with AMICCOM FAE for detail.
    */                   
    //EnableHS();                     
		//EnableCache();
                     
    /* How to switch MCU clock from High Speed Mode to normal mode.
		Step1 : Cache Disable
		Step2 : HS Disable(XREF_PLL = 12.8MHz)
    */
		//DisableCache();
    //DisableHS();
		
    /* 
    How To Set RF Channel
    RF Base Freq : 430.001MHz
    Channel Step : 0.1MHz
    SetCH        : 10
    Range        : 430.001MHz ~ 434.701MHz
    RF Frequency = RF base Freq + (Channel Step * SetCH) = 430.001MHz + ( 0.1MHz * 10 ) = 431.001MHz 
    */		


    A9139M0_WriteID();
    TXPower ( 63, 2 , 1);// , SelectConfig); //TBG=12~63 TDC=0~3 PAC=0~1 

    FIFOLength ( RF_Length);
    TXModeSel ( FIFO);// , SelectConfig);
    TXModulation ( ENABLE);// , SelectConfig);

    CODE1_Reg = CODE1_Reg |0x00000009;
    RADIO->CODE1 = CODE1_Reg;//0x3D580309;//CODE1_Reg; CRCS MSCRC

    RTC_Enable();

    InitLink();
    
    InitTimer0();
    InitTimer1();
    InitDualTimer1();
    InitUART0();

    RF_SetBBIO( 0, 1, 1, ENABLE );
    
//Auto Rssi
    ADC_Reg = ADC_Reg & 0xFFFFF0E7;
    ADC_Reg = ADC_Reg | 0x00000018;
    RADIO->ADC = ADC_Reg;//0x00200380;//0x50001240
    

    NVIC_EnableIRQ(TIMER0_IRQn);
    NVIC_EnableIRQ(TIMER1_IRQn);
    NVIC_EnableIRQ(DUALTIMER_IRQn);
    __enable_irq();

    EnableDualTimer1();
    for (i=0;i<3;i++)
    {
GPIO0->DATAOUT_PIN.P00 = 0;
GPIO0->DATAOUT_PIN.P01 = 0;
GPIO0->DATAOUT_PIN.P02 = 0;
        while (DualTimer1_20msCnt!=25)
            __NOP();
GPIO0->DATAOUT_PIN.P00 = 1;
GPIO0->DATAOUT_PIN.P01 = 1;
GPIO0->DATAOUT_PIN.P02 = 1;
        while (DualTimer1_20msCnt!=0)
            __NOP();
    }

    DisableDualTimer1();

    while ( 1 )
    {
        if (Flag1.bit.NodeModeFlag)//==MASTER)
        {
            //MasterTxDatatInit();
            SetMasterTx_RSSI_Threshold(150);
            SetMasterDataLostBackLinkMode(5);
            TxDatatInit();

            EnableTimer0();
            while(1)
            {
                if (Flag1.bit.MasterProcessBusyFlag)
                {
                    MasterProcess();
                    if (Flag1.bit.MasterUartOutFlag)
                    {
                        MasterUartOut();
                        Flag1.bit.MasterUartOutFlag = 0;
                    }
                    if(Flag1.bit.MasterSetTxFlag)
                    {
                        MasterTxDatatSet();
                        Flag1.bit.MasterSetTxFlag = 0 ;
                    }
                }
            }
        }
        else //slvae node
        {
            SetSlaveDataLostBackLinkMode(5);
            SetSlaveLinkTimeout(6000);
            SetSlaveReLinkTime(5);
            SetSlaveReLinkSleepTimer(10);
            SlaveProcessFristStart();
            TxDatatInit();
            
            TestReceiveCnt = 0;
            
            while(1)
            {
                if (Flag1.bit.SlaveProcessBusyFlag)
                {
                    SlaveProcess();
                    UartOutFlag = 1;
                    if(NodeReceive[SlaveNodeNum] != TestReceiveCnt )
                    {
                        TestReceiveCnt = NodeReceive[SlaveNodeNum];
                        TestDataCnt0++;
                        if (TestDataCnt0==0)
                        {
                            TestDataCnt1++;
                            if (TestDataCnt1==0)
                                TestDataCnt2++;
                        }
                    }
                }
                else
                {
                    //Uart output
                    if ((UartOutFlag))
                    {
                        UartOutFlag = 0;
                        SlaveUartOut();
                        
                        while (Uart_TxLen<Uart_TxCnt)
                        {
                            __NOP();//_nop_();
                        }
                        ADC_Val = ADC12B_Measure ( ADC12B, 1 );
                        SlaveTxDatatSet();
                    }
                    SlavePowerDown();
                }
            }
        }
    }
}
